Summary: A tool for automatically mounting and unmounting filesystems
Name:    autofs
Version: 5.1.9
Release: 2%{?dist}
License: GPLv2+
Url:     https://www.kernel.org
Source0:  https://www.kernel.org/pub/linux/daemons/autofs/v5/autofs-%{version}.tar.gz
Source1: autofs.service
Source2: autofs.conf
Source3: autofs.sysconfig


BuildRequires: systemd-units, systemd-devel
BuildRequires: autoconf, openldap-devel, bison, flex, libxml2-devel
BuildRequires: cyrus-sasl-devel, openssl-devel module-init-tools util-linux
BuildRequires: e2fsprogs libtirpc-devel libsss_autofs libnsl2-devel
BuildRequires: pkgconfig krb5-devel
BuildRequires: make, gcc

Requires: bash coreutils sed gawk grep module-init-tools /bin/ps
Requires(post): systemd-sysv
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units


%description
The goal of autofs is to provide on-demand mounting and race free automatic unmounting
of various other filesystems. This provides two key advantages:

1.There is no need to delay boot until all filesystems that might be needed are mounted.
Processes that try to access those slow filesystems might be delayed but other processes
can continue freely. This is particularly important for network filesystems (e.g. NFS)
or filesystems stored on media with a media-changing robot.

2.The names and locations of filesystems can be stored in a remote database and can change
at any time. The content in that data base at the time of access will be used to provide
a target for the access. The interpretation of names in the filesystem can even be
programmatic rather than database-backed, allowing wildcards for example, and can vary
based on the user who first accessed a name.



%prep
%autosetup -n %{name}-%{version} -p1
echo %{version}-%{release} > .version



%build
LDFLAGS=-Wl,-z,now
%configure \
	--disable-mount-locking \
	--enable-ignore-busy \
	--enable-force-shutdown \
	--without-hesiod \
	--with-libtirpc \
        --with-systemd \
        --enable-fedfs

%make_build initdir=%{_initrddir} DONTSTRIP=1

%install
install -d -m755 %{buildroot}%{_unitdir}
mkdir -p -m755 %{buildroot}%{_sbindir}
mkdir -p -m755 %{buildroot}%{_libdir}/autofs
mkdir -p -m755 %{buildroot}%{_mandir}/{man5,man8}
mkdir -p -m755 %{buildroot}/etc/sysconfig
mkdir -p -m755 %{buildroot}/etc/auto.master.d

%make_install mandir=%{_mandir} initdir=%{_initrddir} systemddir=%{_unitdir} INSTALLROOT=%{buildroot}
install -m755 -d %{buildroot}/misc
find %{buildroot} -type f -name autofs.service -exec rm -f {} \;
install -m644 %{SOURCE1} %{buildroot}%{_unitdir}/autofs.service
install -m644 %{SOURCE2} %{buildroot}/etc/autofs.conf
install -m644 %{SOURCE3} %{buildroot}/etc/sysconfig/autofs
install -m644 samples/auto.master %{buildroot}/etc/auto.master
install -m644 samples/auto.misc %{buildroot}/etc/auto.misc
install -m755 samples/auto.net %{buildroot}/etc/auto.net
install -m755 samples/auto.smb %{buildroot}/etc/auto.smb
install -m600 samples/autofs_ldap_auth.conf %{buildroot}/etc/autofs_ldap_auth.conf

%post
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service


%files
%license COPY*
%doc CREDITS INSTALL README* samples/ldap* samples/autofs.schema
%config %{_unitdir}/autofs.service
%config(noreplace,missingok) /etc/auto.master
%config(noreplace) /etc/autofs.conf
%config(noreplace,missingok) /etc/auto.misc
%config(noreplace,missingok) /etc/auto.net
%config(noreplace,missingok) /etc/auto.smb
%config(noreplace) /etc/sysconfig/autofs
%config(noreplace) /etc/autofs_ldap_auth.conf
%{_sbindir}/automount
%{_sbindir}/mount.fedfs
%{_sbindir}/fedfs-map-nfs4
%dir /etc/auto.master.d
%{_libdir}/libautofs.so
%{_libdir}/autofs/
%{_mandir}/*/*

%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.1.9-2
- Rebuilt for loongarch release

* Wed Jan 03 2024 Upgrade Robot <upbot@opencloudos.org> - 5.1.9-1
- Upgrade to version 5.1.9

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.1.8-5
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Jul 14 2023 Wang Guodong <gordonwwang@tencent.com> - 5.1.8-4
- Rebuilt for sssd 2.9.0

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.1.8-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.1.8-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Nov 17 2022 cunshunxia <cunshunxia@tencent.com> - 5.1.8-1
- initial build
